QueryString

Struct QueryString 

pub struct QueryString { /* private fields */ }
Used to bind a form input element to a form data element. Note that QueryString supports a maximal depth of 16. Creating query strings consisting of more than 16 parts will panic.

Implementations

Source

impl QueryString

pub fn iter(&self) -> impl Iterator<Item = &QueryStringPart>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn extends(&self, other: &Self) -> Option<QueryString>

Checks whether the current query string extends the other query string.

pub fn join(self, other: Self) -> Self

Joins two QueryStrings.

pub fn add(self, part: QueryStringPart) -> Self

pub fn add_index(self, index: usize) -> Self

pub fn add_key<K: AsRef<str>>(self, key: K) -> Self

pub fn first(&self) -> Option<QueryStringPart>

pub fn remove(self) -> Self

pub fn remove_first(self) -> Self